@@ -67,8 +67,8 @@ construct_password_dialog (gboolean is_proxy_authentication, const GnomeVFSModul
 	dialog = EEL_PASSWORD_DIALOG (eel_password_dialog_new (
 			_("Authentication Required"),
 			message,
-			_(""),
-			_(""),
+			"",
+			"",
 			FALSE));
 
 	g_free (message);
@@ -124,7 +124,7 @@ authentication_dialog_button_clicked (GtkDialog *dialog,
 {
 	DEBUG_MSG (("+%s button: %d\n", G_GNUC_FUNCTION, button_number));
 
-	if (button_number == GNOME_OK) {
+	if (button_number == GTK_RESPONSE_OK) {
 		info->out_args->username 
 			= eel_password_dialog_get_username (EEL_PASSWORD_DIALOG (dialog));
 		info->out_args->password
@@ -164,7 +164,7 @@ present_authentication_dialog_nonblocking (CallbackInfo *info)
 	gtk_window_set_modal (GTK_WINDOW (dialog), FALSE);
 
 	g_signal_connect (dialog, 
-			     "clicked", 
+			     "response", 
 			     G_CALLBACK (authentication_dialog_button_clicked),
 			     info);
 
