@@ -24,18 +24,17 @@
 
 #include <config.h>
 #include "nautilus-mime-actions.h"
-
+ 
 #include "nautilus-file-attributes.h"
 #include "nautilus-file.h"
-#include <eel/eel-glib-extensions.h>
 #include "nautilus-metadata.h"
+#include <bonobo-activation/bonobo-activation-activate.h>
+#include <eel/eel-glib-extensions.h>
 #include <eel/eel-string.h>
 #include <libgnomevfs/gnome-vfs-application-registry.h>
-#include <libgnomevfs/gnome-vfs-mime-info.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <stdio.h>
- 
+
 static int         gnome_vfs_mime_application_has_id             (GnomeVFSMimeApplication  *application,
 								  const char               *id);
 static int         gnome_vfs_mime_id_matches_application         (const char               *id,
@@ -46,7 +45,7 @@ static gboolean    string_not_in_list                            (const char
 								  GList                    *list);
 static char       *mime_type_get_supertype                       (const char               *mime_type);
 static GList      *get_explicit_content_view_iids_from_metafile  (NautilusFile             *file);
-static gboolean    server_has_content_requirements               (OAF_ServerInfo           *server);
+static gboolean    server_has_content_requirements               (Bonobo_ServerInfo           *server);
 static gboolean   application_supports_uri_scheme                (gpointer                 data,
 								  gpointer                 uri_scheme);
 static GList      *nautilus_do_component_query                   (const char               *mime_type,
@@ -64,15 +63,7 @@ static char      **strv_concat                                   (char
 static gboolean
 is_known_mime_type (const char *mime_type)
 {
-	if (mime_type == NULL) {
-		return FALSE;
-	}
-	
-	if (g_strcasecmp (mime_type, GNOME_VFS_MIME_TYPE_UNKNOWN) == 0) {
-		return FALSE;
-	}
-	
-	return TRUE;
+	return eel_strcasecmp (mime_type, GNOME_VFS_MIME_TYPE_UNKNOWN) != 0;
 }
 
 static gboolean
@@ -149,9 +140,9 @@ nautilus_mime_get_default_action_type_for_file (NautilusFile *file)
 		g_free (mime_type);
 		return action_type;
 	} else {
-		if (g_strcasecmp (action_type_string, "application") == 0) {
+		if (g_ascii_strcasecmp (action_type_string, "application") == 0) {
 			return GNOME_VFS_MIME_ACTION_TYPE_APPLICATION;
-		} else if (g_strcasecmp (action_type_string, "component") == 0) {
+		} else if (g_ascii_strcasecmp (action_type_string, "component") == 0) {
 			return GNOME_VFS_MIME_ACTION_TYPE_COMPONENT;
 		} else {
 			return GNOME_VFS_MIME_ACTION_TYPE_NONE;
@@ -218,7 +209,7 @@ nautilus_mime_get_default_application_for_file_internal (NautilusFile *file,
 	default_application_string = nautilus_file_get_metadata 
 		(file, NAUTILUS_METADATA_KEY_DEFAULT_APPLICATION, NULL);
 
-	/* FIXME bugzilla.eazel.com 5085: should fall back to normal default 
+	/* FIXME bugzilla.gnome.org 45085: should fall back to normal default 
 	   if user-specified default is bogus */
 
 	if (default_application_string == NULL) {
@@ -297,10 +288,10 @@ nautilus_mime_get_default_component_sort_conditions (NautilusFile *file, char *d
 			prev = sort_conditions[1];
 			
 			if (p->next != NULL) {
-				sort_conditions[1] = g_strconcat (prev, ((OAF_ServerInfo *) (p->data))->iid, 
+				sort_conditions[1] = g_strconcat (prev, ((Bonobo_ServerInfo *) (p->data))->iid, 
 								  "','", NULL);
 			} else {
-				sort_conditions[1] = g_strconcat (prev, ((OAF_ServerInfo *) (p->data))->iid, 
+				sort_conditions[1] = g_strconcat (prev, ((Bonobo_ServerInfo *) (p->data))->iid, 
 								  "'])", NULL);
 			}
 			g_free (prev);
@@ -334,18 +325,18 @@ nautilus_mime_get_default_component_sort_conditions (NautilusFile *file, char *d
 	return sort_conditions;
 }	
 
-static OAF_ServerInfo *
+static Bonobo_ServerInfo *
 nautilus_mime_get_default_component_for_file_internal (NautilusFile *file,
 						       gboolean     *user_chosen)
 {
 	GList *info_list;
-	OAF_ServerInfo *mime_default; 
+	Bonobo_ServerInfo *mime_default; 
 	char *default_component_string;
 	char *mime_type;
 	char *uri_scheme;
 	GList *item_mime_types;
 	GList *explicit_iids;
-	OAF_ServerInfo *server;
+	Bonobo_ServerInfo *server;
 	char **sort_conditions;
 	char *extra_requirements;
 	gboolean used_user_chosen_info;
@@ -408,7 +399,7 @@ nautilus_mime_get_default_component_for_file_internal (NautilusFile *file,
 	}
 
 	if (info_list != NULL) {
-		server = OAF_ServerInfo_duplicate (info_list->data);
+		server = Bonobo_ServerInfo_duplicate (info_list->data);
 		gnome_vfs_mime_component_list_free (info_list);
 
 		if (default_component_string != NULL && strcmp (server->iid, default_component_string) == 0) {
@@ -433,7 +424,7 @@ nautilus_mime_get_default_component_for_file_internal (NautilusFile *file,
 }
 
 
-OAF_ServerInfo *
+Bonobo_ServerInfo *
 nautilus_mime_get_default_component_for_file (NautilusFile      *file)
 {
 	return nautilus_mime_get_default_component_for_file_internal (file, NULL);
@@ -442,7 +433,7 @@ nautilus_mime_get_default_component_for_file (NautilusFile      *file)
 gboolean
 nautilus_mime_is_default_component_for_file_user_chosen (NautilusFile      *file)
 {
-	OAF_ServerInfo *component;
+	Bonobo_ServerInfo *component;
 	gboolean user_chosen;
 
 	component = nautilus_mime_get_default_component_for_file_internal (file, &user_chosen);
@@ -486,7 +477,8 @@ nautilus_mime_get_short_list_applications_for_file (NautilusFile      *file)
 	result = eel_g_list_partition (result, application_supports_uri_scheme,
 					    uri_scheme, &removed);
 	gnome_vfs_mime_application_list_free (removed);
-
+	g_free (uri_scheme);
+	
 	metadata_application_add_ids = nautilus_file_get_metadata_list 
 		(file,
 		 NAUTILUS_METADATA_KEY_SHORT_LIST_APPLICATION_ADD,
@@ -556,7 +548,7 @@ nautilus_mime_get_short_list_components_for_file (NautilusFile *file)
 	GList *metadata_component_add_ids;
 	GList *metadata_component_remove_ids;
 	GList *p;
-	OAF_ServerInfo *component;
+	Bonobo_ServerInfo *component;
 	GList *explicit_iids;
 	char *extra_sort_conditions[2];
 	char *extra_requirements;
@@ -588,7 +580,7 @@ nautilus_mime_get_short_list_components_for_file (NautilusFile *file)
 	iids = NULL;
 
 	for (p = servers; p != NULL; p = p->next) {
-		component = (OAF_ServerInfo *) p->data;
+		component = (Bonobo_ServerInfo *) p->data;
 
 		iids = g_list_prepend (iids, component->iid);
 	}
@@ -750,7 +742,7 @@ nautilus_mime_actions_file_needs_full_file_attributes (NautilusFile *file)
 	needs_full_attributes = FALSE;
 
 	for (p = info_list; p != NULL; p = p->next) {
-		needs_full_attributes |= server_has_content_requirements ((OAF_ServerInfo *) (p->data));
+		needs_full_attributes |= server_has_content_requirements ((Bonobo_ServerInfo *) (p->data));
 	}
 	
 	gnome_vfs_mime_component_list_free (info_list);
@@ -939,7 +931,7 @@ nautilus_mime_set_short_list_applications_for_file (NautilusFile      *file,
 		 NAUTILUS_METADATA_SUBKEY_APPLICATION_ID,
 		 remove_list);
 
-	/* FIXME bugzilla.eazel.com 1269: 
+	/* FIXME bugzilla.gnome.org 41269: 
 	 * need to free normal_short_list, normal_short_list_ids, add_list, remove_list 
 	 */
 
@@ -967,7 +959,7 @@ nautilus_mime_set_short_list_components_for_file (NautilusFile      *file,
 	
 	normal_short_list_ids = NULL;
 	for (p = normal_short_list; p != NULL; p = p->next) {
-		normal_short_list_ids = g_list_prepend (normal_short_list_ids, ((OAF_ServerInfo *) p->data)->iid);
+		normal_short_list_ids = g_list_prepend (normal_short_list_ids, ((Bonobo_ServerInfo *) p->data)->iid);
 	}
 
 	/* compute delta */
@@ -986,7 +978,7 @@ nautilus_mime_set_short_list_components_for_file (NautilusFile      *file,
 		 NAUTILUS_METADATA_SUBKEY_COMPONENT_IID,
 		 remove_list);
 
-	/* FIXME bugzilla.eazel.com 1269: 
+	/* FIXME bugzilla.gnome.org 41269: 
 	 * need to free normal_short_list, normal_short_list_ids, add_list, remove_list 
 	 */
 
@@ -1240,7 +1232,7 @@ get_explicit_content_view_iids_from_metafile (NautilusFile *file)
 }
 
 static char *
-make_oaf_query_for_explicit_content_view_iids (GList *view_iids)
+make_bonobo_activation_query_for_explicit_content_view_iids (GList *view_iids)
 {
         GList *p;
         char  *iid;
@@ -1277,7 +1269,7 @@ make_oaf_query_for_explicit_content_view_iids (GList *view_iids)
 }
 
 static char *
-make_oaf_query_with_known_mime_type (const char *mime_type, 
+make_bonobo_activation_query_with_known_mime_type (const char *mime_type, 
 				     const char *uri_scheme, 
 				     GList      *explicit_iids, 
 				     const char *extra_requirements)
@@ -1288,7 +1280,7 @@ make_oaf_query_with_known_mime_type (const char *mime_type,
 
         mime_supertype = mime_type_get_supertype (mime_type);
 
-        explicit_iid_query = make_oaf_query_for_explicit_content_view_iids (explicit_iids);
+        explicit_iid_query = make_bonobo_activation_query_for_explicit_content_view_iids (explicit_iids);
 
         result = g_strdup_printf 
                 (
@@ -1319,7 +1311,7 @@ make_oaf_query_with_known_mime_type (const char *mime_type,
 
 		 /* One of two possibilties */
 
-		 /* FIXME bugzilla.eazel.com 2542: this comment is not very clear. */
+		 /* FIXME bugzilla.gnome.org 42542: this comment is not very clear. */
 		 /* 1 The mime type and URI scheme match the supported
                     attributes. */
 
@@ -1379,14 +1371,14 @@ make_oaf_query_with_known_mime_type (const char *mime_type,
 }
 
 static char *
-make_oaf_query_with_uri_scheme_only (const char *uri_scheme, 
+make_bonobo_activation_query_with_uri_scheme_only (const char *uri_scheme, 
 				     GList      *explicit_iids, 
 				     const char *extra_requirements)
 {
         char *result;
         char *explicit_iid_query;
         
-        explicit_iid_query = make_oaf_query_for_explicit_content_view_iids (explicit_iids);
+        explicit_iid_query = make_bonobo_activation_query_for_explicit_content_view_iids (explicit_iids);
 
         result = g_strdup_printf 
                 (
@@ -1413,7 +1405,7 @@ make_oaf_query_with_uri_scheme_only (const char *uri_scheme,
                    */
                   "AND (NOT bonobo:supported_mime_types.defined ()))"
 
-		  /* FIXME bugzilla.eazel.com 2542: improve the comment explaining this. */
+		  /* FIXME bugzilla.gnome.org 42542: improve the comment explaining this. */
 		  
 		  /* This attribute allows uri schemes to be supported
 		     even for unsupported mime types or no mime type. */
@@ -1444,6 +1436,8 @@ make_oaf_query_with_uri_scheme_only (const char *uri_scheme,
                   , explicit_iid_query,
 		  extra_requirements != NULL ? extra_requirements : "true");
 
+	g_free (explicit_iid_query);
+	
         return result;
 }
 
@@ -1492,13 +1486,13 @@ mime_type_hash_table_destroy (GHashTable *table)
 
 
 static gboolean
-server_has_content_requirements (OAF_ServerInfo *server)
+server_has_content_requirements (Bonobo_ServerInfo *server)
 {
-        OAF_Property *prop;
+        Bonobo_ActivationProperty *prop;
 	
-        prop = oaf_server_info_prop_find (server, "nautilus:required_directory_content_mime_types");
+        prop = bonobo_server_info_prop_find (server, "nautilus:required_directory_content_mime_types");
 
-        if (prop == NULL || prop->v._d != OAF_P_STRINGV) {
+        if (prop == NULL || prop->v._d != Bonobo_ACTIVATION_P_STRINGV) {
                 return FALSE;
         } else {
 		return TRUE;
@@ -1506,12 +1500,12 @@ server_has_content_requirements (OAF_ServerInfo *server)
 }
 
 static gboolean
-server_matches_content_requirements (OAF_ServerInfo *server, 
+server_matches_content_requirements (Bonobo_ServerInfo *server, 
 				     GHashTable     *type_table, 
 				     GList          *explicit_iids)
 {
-        OAF_Property *prop;
-        GNOME_stringlist types;
+        Bonobo_ActivationProperty *prop;
+        Bonobo_StringList types;
         guint i;
 
         /* Components explicitly requested in the metafile are not capability tested. */
@@ -1522,7 +1516,7 @@ server_matches_content_requirements (OAF_ServerInfo *server,
         if (!server_has_content_requirements (server)) {
                 return TRUE;
         } else {
-        	prop = oaf_server_info_prop_find (server, "nautilus:required_directory_content_mime_types");
+        	prop = bonobo_server_info_prop_find (server, "nautilus:required_directory_content_mime_types");
 
                 types = prop->v._u.value_stringv;
 
@@ -1557,42 +1551,42 @@ nautilus_do_component_query (const char        *mime_type,
 			     char             **extra_sort_criteria,
 			     char              *extra_requirements)
 { 
-	OAF_ServerInfoList *oaf_result;
+	Bonobo_ServerInfoList *bonobo_activation_result;
 	char *query;
 	GList *retval;
 	char **all_sort_criteria;
 	CORBA_Environment ev;
 
-        oaf_result = NULL;
+        bonobo_activation_result = NULL;
         query = NULL;
 
         if (is_known_mime_type (mime_type)) {
-                query = make_oaf_query_with_known_mime_type (mime_type, uri_scheme, explicit_iids, extra_requirements);
+                query = make_bonobo_activation_query_with_known_mime_type (mime_type, uri_scheme, explicit_iids, extra_requirements);
         } else {
-                query = make_oaf_query_with_uri_scheme_only (uri_scheme, explicit_iids, extra_requirements);
+                query = make_bonobo_activation_query_with_uri_scheme_only (uri_scheme, explicit_iids, extra_requirements);
         }
 
 	all_sort_criteria = strv_concat (extra_sort_criteria, nautilus_sort_criteria);
 
 	CORBA_exception_init (&ev);
 
-	oaf_result = oaf_query (query, all_sort_criteria, &ev);
+	bonobo_activation_result = bonobo_activation_query (query, all_sort_criteria, &ev);
 	
 	g_free (all_sort_criteria);
 	g_free (query);
 
 	retval = NULL;
 
-        if (ev._major == CORBA_NO_EXCEPTION && oaf_result != NULL && oaf_result->_length > 0) {
+        if (ev._major == CORBA_NO_EXCEPTION && bonobo_activation_result != NULL && bonobo_activation_result->_length > 0) {
                 GHashTable *content_types;
                 guint i;
            
                 content_types = mime_type_list_to_hash_table (item_mime_types);
                 
-                for (i = 0; i < oaf_result->_length; i++) {
-                        OAF_ServerInfo *server;
+                for (i = 0; i < bonobo_activation_result->_length; i++) {
+                        Bonobo_ServerInfo *server;
 
-                        server = &oaf_result->_buffer[i];
+                        server = &bonobo_activation_result->_buffer[i];
 
                         if (ignore_content_mime_types || 
 			    server_matches_content_requirements (server, content_types, explicit_iids)) {
@@ -1602,7 +1596,7 @@ nautilus_do_component_query (const char        *mime_type,
                                 if (server->iid != NULL && strcmp (server->iid, "OAFIID:Bonobo_Sample_Text") != 0) {
                                 	retval = g_list_prepend
                                         	(retval, 
-						 OAF_ServerInfo_duplicate (server));
+						 Bonobo_ServerInfo_duplicate (server));
                         	}
                         }
                 }
@@ -1610,7 +1604,7 @@ nautilus_do_component_query (const char        *mime_type,
                 mime_type_hash_table_destroy (content_types);
         }
 
-	CORBA_free (oaf_result);
+	CORBA_free (bonobo_activation_result);
 
 	CORBA_exception_free (&ev);
 	
@@ -1693,7 +1687,7 @@ application_supports_uri_scheme (gpointer data,
 
 	/* The default supported uri scheme is "file" */
 	if (application->supported_uri_schemes == NULL
-	    && g_strcasecmp ((const char *) uri_scheme, "file") == 0) {
+	    && g_ascii_strcasecmp ((const char *) uri_scheme, "file") == 0) {
 		return TRUE;
 	}
 	return g_list_find_custom (application->supported_uri_schemes,
