@@ -26,21 +26,28 @@
 #ifndef FM_ERROR_REPORTING_H
 #define FM_ERROR_REPORTING_H
 
-#include <glib.h>
+#include <gtk/gtkwindow.h>
 #include <libgnomevfs/gnome-vfs-types.h>
-#include <libnautilus-extensions/nautilus-file.h>
+#include <libnautilus-private/nautilus-file.h>
 
+void fm_report_error_loading_directory	 (NautilusFile   *file,
+					  GnomeVFSResult  error_code,
+					  GtkWindow	 *parent_window);
 void fm_report_error_renaming_file       (NautilusFile   *file,
 					  const char     *new_name,
-					  GnomeVFSResult  error_code);
+					  GnomeVFSResult  error_code,
+					  GtkWindow	 *parent_window);
 void fm_report_error_setting_permissions (NautilusFile   *file,
-					  GnomeVFSResult  error_code);			    
+					  GnomeVFSResult  error_code,			    
+					  GtkWindow	 *parent_window);
 void fm_report_error_setting_owner       (NautilusFile   *file,
-					  GnomeVFSResult  error_code);  
+					  GnomeVFSResult  error_code,  
+					  GtkWindow	 *parent_window);
 void fm_report_error_setting_group       (NautilusFile   *file,
-					  GnomeVFSResult  error_code);
+					  GnomeVFSResult  error_code,
+					  GtkWindow	 *parent_window);
 
-/* FIXME bugzilla.eazel.com 2394: Should this file be renamed or should these be moved? */
+/* FIXME bugzilla.gnome.org 42394: Should this file be renamed or should this function be moved? */
 void fm_rename_file                      (NautilusFile   *file,
 					  const char     *new_name);
 
